{
  "type": "record",
  "name": "MLPrimaryKeyKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "doc": "Key for an MLPrimaryKey",
  "fields": [
    {
      "name": "featureNamespace",
      "type": "string",
      "doc": "Namespace for the primary key",
      "Searchable": {
        "fieldType": "TEXT_PARTIAL"
      }
    },
    {
      "name": "name",
      "type": "string",
      "doc": "Name of the primary key",
      "Searchable": {
        "boostScore": 8.0,
        "enableAutocomplete": true,
        "fieldType": "TEXT_PARTIAL"
      }
    }
  ],
  "Aspect": {
    "name": "mlPrimaryKeyKey",
    "keyForEntity": "mlPrimaryKey",
    "entityCategory": "core",
    "entityAspects": [
      "glossaryTerms",
      "editableMlPrimaryKeyProperties",
      "domains"
    ]
  }
}